import {Component, Input, OnInit} from '@angular/core'
import {Employee, EmployeeGroup, EmployeePermission} from '../../../shared/model/employee'
import {GroupService} from '../../services/group.service'
import {AccountService} from '../../../accounts/services/account.service'
import {Observable} from 'rxjs'

@Component({
  selector: 'cre-employees-list',
  templateUrl: './employees-list.component.html',
  styleUrls: ['./employees-list.component.sass']
})
export class EmployeesListComponent implements OnInit {
  @Input() group: EmployeeGroup

  employees$: Observable<Employee[]> | null
  columns = ['id', 'firstName', 'lastName', 'edit']

  constructor(
    private accountService: AccountService,
    private groupService: GroupService
  ) {
  }

  ngOnInit(): void {
    this.employees$ = this.groupService.getEmployeesForGroup(this.group.id)
  }

  get canEditEmployee(): boolean {
    return this.accountService.hasPermission(EmployeePermission.EDIT_EMPLOYEE)
  }
}
