import {Component} from '@angular/core'
import {MaterialType} from '../../../shared/model/materialtype.model'
import {ActivatedRoute, Router} from '@angular/router'
import {ErrorHandlingComponent} from '../../../shared/components/subscribing.component'
import {MaterialTypeService} from '../../service/material-type.service'
import {FormField} from '../../../shared/components/entity-add/entity-add.component'
import {Validators} from '@angular/forms'
import {ErrorModel, ErrorService} from '../../../shared/service/error.service'

@Component({
  selector: 'cre-edit',
  templateUrl: './edit.component.html',
  styleUrls: ['./edit.component.sass']
})
export class EditComponent extends ErrorHandlingComponent {
  materialType: MaterialType | null
  formFields: FormField[] = [
    {
      name: 'name',
      label: 'Nom',
      icon: 'form-textbox',
      type: 'text',
      validator: Validators.required,
      errorMessages: [
        {conditionFn: (errors) => errors.required, message: 'Un nom est requis'},
      ]
    },
    {
      name: 'prefix',
      label: 'Préfixe',
      icon: 'label-variant',
      type: 'text',
      validator: Validators.compose([Validators.required, Validators.minLength(3), Validators.maxLength(3)]),
      errorMessages: [
        {conditionFn: (errors) => errors.required, message: 'Un préfixe est requis'},
        {
          conditionFn: (errors) => errors.minlength || errors.maxlength,
          message: 'Le préfixe doit faire exactement 3 caractères'
        }
      ]
    }
  ]
  submittedValues: any | null

  handledErrorModels: ErrorModel[] = [{
    filter: error => error.status === 409 && error.error.id === this.submittedValues.name,
    messageProducer: error => `Un type de produit avec le nom '${error.error.id}' existe déjà`
  }, {
    filter: error => error.status === 409 && error.error.id === this.submittedValues.prefix,
    messageProducer: error => `Un type de produit avec le préfixe '${error.error.id}' existe déjà`
  }]

  constructor(
    private materialTypeService: MaterialTypeService,
    errorService: ErrorService,
    router: Router,
    activatedRoute: ActivatedRoute
  ) {
    super(errorService, activatedRoute, router)
  }

  ngOnInit() {
    super.ngOnInit()

    const id = parseInt(this.activatedRoute.snapshot.paramMap.get('id'))
    this.subscribeEntityById(
      this.materialTypeService,
      id,
      materialType => this.materialType = materialType,
      '/employee/list'
    )
  }

  submit(values) {
    this.submittedValues = values
    this.subscribeAndNavigate(
      this.materialTypeService.update(this.materialType.id, values.name, values.prefix),
      '/catalog/materialtype/list'
    )
  }

  delete() {
    this.subscribeAndNavigate(
      this.materialTypeService.delete(this.materialType.id),
      '/catalog/materialtype/list'
    )
  }
}
